@@ -1720,8 +1720,11 @@ gen_log:log D " $pattern MATCHED $text"
         -command [namespace code {
                  global cvscfg
                  variable logcanvas
+                 variable my_idx
                  set cvscfg(loggeom) [wm geometry $logcanvas]
                  destroy $logcanvas
+                 catch {namespace delete ::cvs_branchlog::$my_idx}
+                 catch {namespace delete ::svn_branchlog::$my_idx}
                  namespace delete [namespace current]
                  exit_cleanup 0
                }]
