@@ -20,67 +20,78 @@
 # arguments and creates the proper bindings for entering
 # and leaving the button
 
-proc set_tooltips {widget name} {
-  bind $widget <Enter> "internal_tooltips_PopUp %W $name %X %Y"
-  bind $widget <Leave> "internal_tooltips_PopDown %W"
-  bind $widget <Button-1> "internal_tooltips_PopDown %W"
+proc set_tooltips { widget name } {
+  global cvsglb
+
+  bind $widget <Enter> "
+    catch { after 500 { internal_tooltips_PopUp %W $name } } \
+        cvsglb(tooltip_id)
+  "
+  bind $widget <Leave> "internal_tooltips_PopDown"
+  bind $widget <Button-1> "internal_tooltips_PopDown"
 }
 
 ##############################
 # internal_tooltips_PopUp is used to activate the tooltip window
 
-proc internal_tooltips_PopUp {wid name X Y} {
-  global cvscfg
+proc internal_tooltips_PopUp { wid name } {
+  global cvscfg cvsglb
 
   # get rid of other existing tooltips
-  catch {destroy .tooltips_wind}
+  catch { destroy .tooltips_wind }
+
   toplevel .tooltips_wind -class ToolTip
   set size_changed 0
   set bg [option get .tooltips_wind background background]
   set fg [option get .tooltips_wind foreground foreground]
 
+  # get the cursor position
+  set X [winfo pointerx $wid]
+  set Y [winfo pointery $wid]
+
   # add a slight offset to make tooltips fall below cursor
-  set Y [expr {$Y+15}]
+  set Y [expr { $Y + 20 }]
+
   # Now pop up the new widgetLabel
   wm overrideredirect .tooltips_wind 1
-  wm geometry .tooltips_wind +${X}+${Y}
-  label .tooltips_wind.l -text $name -border 2 -relief raised \
-    -font $cvscfg(listboxfont) -bg $bg -fg $fg
-  pack .tooltips_wind.l -in .tooltips_wind
+  wm geometry .tooltips_wind +$X+$Y
+  label .tooltips_wind.l \
+      -text $name \
+      -border 2 \
+      -relief raised \
+      -font $cvscfg(listboxfont) \
+      -background $bg \
+      -foreground $fg
+  pack .tooltips_wind.l
+
   # make invisible
   wm withdraw .tooltips_wind
   update idletasks
+
   # adjust for bottom of screen
-  if {$Y+[winfo reqheight .tooltips_wind]>[winfo screenheight .]} {
-    set Y [expr {$Y-($Y+[winfo reqheight .tooltips_wind]-[winfo screenheight .])-30}]
+  if { ($Y + [winfo reqheight .tooltips_wind]) > [winfo screenheight .] } {
+    set Y [expr { $Y - [winfo reqheight .tooltips_wind] - 25 }]
     set size_changed 1
   }
   # adjust for right border of screen
-  if {$X+[winfo reqwidth .tooltips_wind]>[winfo screenwidth .]} {
-    set X [expr {$X-($X+[winfo reqwidth .tooltips_wind]-[winfo screenwidth .])}]
+  if { ($X + [winfo reqwidth .tooltips_wind]) > [winfo screenwidth .] } {
+    set X [expr { [winfo screenwidth .] - [winfo reqwidth .tooltips_wind] }]
     set size_changed 1
   }
   # reset position
-  if {$size_changed==1} {
-    wm geometry .tooltips_wind +${X}+${Y}
+  if { $size_changed == 1 } {
+    wm geometry .tooltips_wind +$X+$Y
   }
   # make visible
   wm deiconify .tooltips_wind
+
+  # make tooltip dissappear after 5 sec
+  set cvsglb(tooltip_id) [after 5000 { internal_tooltips_PopDown }]
 }
 
-proc internal_tooltips_PopDown {widget} {
-  catch {destroy .tooltips_wind}
-  $widget configure -relief raised
-}
+proc internal_tooltips_PopDown { } {
+  global cvsglb
 
-proc internal_button_press {widget} {
-  catch {destroy .tooltips_wind}
-  $widget configure -relief sunken
-  eval [lindex [$widget configure -command ] 4]
+  after cancel $cvsglb(tooltip_id)
+  catch { destroy .tooltips_wind }
 }
-
-proc internal_button_release {widget} {
-  
-  $widget configure -relief raised
-}
-
